"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os,sys

from filesysobjects.FileSysObjects import setUpperTreeSearchPath,\
    unescapeFilePath


#
#######################
#
class CallUnits(unittest.TestCase):
    

    
    

    #
    # Create by object
    #
    def testCase000(self):
        """Check defaults.
        """
        _s = sys.path[:]

        start = os.path.abspath(os.path.dirname(__file__))
        top = None
        res = []
        ret = setUpperTreeSearchPath(start,top,res) #@UnusedVariable
        
        resx = [
            os.path.abspath(os.path.dirname(__file__)),
        ]
        resx = map(os.path.normpath,resx)
        
        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        res = map(unescapeFilePath, res)
        resx = map(unescapeFilePath, resx)

        assert resx == res
        pass

if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import
from __future__ import print_function

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='202b4a86-488d-4d9b-856e-4aa7fd05b1e5'

__docformat__ = "restructuredtext en"

import unittest
import os,sys



#
#######################
#

class CallUnits(unittest.TestCase):

    def testCase000(self):
        _s = sys.path[:]
        #
        # set search for the call of 'myscript.sh'
        from filesysobjects.FileSysObjects import setUpperTreeSearchPath
        setUpperTreeSearchPath(os.path.abspath(os.path.dirname(__file__)),'pyfilesysobjects')
        from tests.dummymodules.Dummy0 import Dummy0
        
        d = Dummy0()
        d.set(1)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        pass

#
#######################
#

if __name__ == '__main__':
    unittest.main()




"""Demonstrates the application of hierarchical search paths on Microsoft-Windows(TM) on drives . 

Type: LFSYS, LDFSYS 

"""
from __future__ import absolute_import

import unittest
import os,sys

from pysourceinfo.PySourceInfo import getPythonPathRel
from filesysobjects.FileSysObjects import setUpperTreeSearchPath,splitAppPrefix,getAppPrefixLocalPath,getTopFromPathString


#
#######################
#
class UseCase(unittest.TestCase):
    
    def testCase_IAS_True(self):
        _s = sys.path[:]
        
        start0 = os.path.abspath(os.path.dirname(__file__)+os.sep+os.path.normpath('/a/b/c'))
        d,p = os.path.splitdrive(start0) #@UnusedVariable
        start1 = os.sep + p #@UnusedVariable
    
        # normalize
        _start_elems = splitAppPrefix(start0,**{'ias':True})
        start= getAppPrefixLocalPath(_start_elems)

        assert start0 == start
        top = 'AppPathSyntax/'
        _top_elems = ('IAS', '', '', top,)
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable

        myplist = [getTopFromPathString('AppPathSyntax',[start])]
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathRel(_res[i],myplist)) 
        resx = [
            'API_options/ias/ias_false/a/b/c', 
            'API_options/ias/ias_false/a/b', 
            'API_options/ias/ias_false/a', 
            'API_options/ias/ias_false', 
            'API_options/ias', 
            'API_options', 
            '.'
        ]
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        assert resx == res
        pass



if __name__ == '__main__':
    unittest.main()



"""Create a plist, find a matching relative filepathname in directory tree.

Calling elementary functions.

* **Data**:
  ::
  
    see 'testdata.examples'
  
  refer also to the manual `[filesystem-elements-as-objects] <path_syntax.html#filesystem-elements-as-objects>`_

* **Call**:
  ::

    import testdata
    import filesysobjects.FileSysObjects
      
    # start of upward search - file is converted into it's containing directory node
    s = os.sep
    any_sub_path = os.path.normpath('examples/a/b0/c/a/b0/c/F')
    spath  = testdata.mypath
    spath += any_sub_path

    # Here an empty list is used for search only. The function adds 
    # entries to the provided list storage, thus e.g. to 'sys.path' too.
    _plist = []

    # 0. build a search path list - if not yet available
    #    adds each directory from spath to its matching 
    #    subnode  "a/b"
    #
    setUpperTreeSearchPath(spath,os.path.normpath('b/B.txt'), _plist)
    rp = findRelPathInSearchPath(spath,_plist)


    _addp = _plist_ref[-1]

    # 1. append an item       
    _px = addPathToSearchPath(_addp, _plist,**{'append':True})

    # 2. remove the item
    delPathFromSearchPath(_addp, _plist)

* **Result**:
  ::

    expected = os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0/F1')

"""
from __future__ import absolute_import
from __future__ import print_function

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

import testdata

from filesysobjects.FileSysObjects import addPathToSearchPath
from filesysobjects.FileSysObjects import delPathFromSearchPath
from filesysobjects.FileSysObjects import setUpperTreeSearchPath
from filesysobjects.FileSysObjects import findRelPathInSearchPath
from filesysobjects.FileSysObjects import clearPath


#
#######################
#
_plist_ref = [ 
    os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0/c'),
    os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0'),
    os.path.normpath(testdata.mypath+'/examples/a/b0/c/a'),
    os.path.normpath(testdata.mypath+'/examples/a/b0/c'),
    os.path.normpath(testdata.mypath+'/examples/a/b0'),
    os.path.normpath(testdata.mypath+'/examples/a'),
]
"""reference data for usecase"""


# start of upward search - file is converted into it's containing directory node
any_sub_path = os.path.normpath('examples/a/b0/c/a/b0/c/F')

spath  = testdata.mypath
spath += os.sep+ any_sub_path
# check environment
assert os.path.exists(spath)

_plist = []
"""test data for incremental update by usecases"""

# 0. build a search path list - if not yet available
#    adds each directory from spath to its matching 
#    subnode  "a/b"
#
setUpperTreeSearchPath(spath,os.path.normpath('a/b0'), _plist)

# validate initial state
assert _plist_ref[:-1] == _plist 

class UseCase(unittest.TestCase):
    def __init__(self,*args,**kargs):
        """Setup reference data as singleton
        """
        super(UseCase,self).__init__(*args,**kargs)

        self._plist = _plist
        self._plist_ref = _plist_ref

        pass

    def test_UseCase000_append(self):
        """1. append an item"""       
        _addp = self._plist_ref[-1]
        _px = addPathToSearchPath(_addp, self._plist,**{'append':True})
        assert _px == len(self._plist_ref)-1 # here just a demo
        assert self._plist_ref == self._plist 
        pass

    def test_UseCase010_prepend_same_again(self):
        """2. append same item again - with success"""
        _addp = self._plist_ref[-1]
        _px = addPathToSearchPath(_addp, self._plist,**{'prepend':True,'redundant':True})
        assert len(self._plist) == len(self._plist_ref)+1 # here just a demo
        assert self._plist_ref == self._plist[1:] 
        assert self._plist[0] == _addp 

    def test_UseCase020_append_try_same_again_nonredundant(self):
        """3. try to add same item again - with failure"""
        _addp = self._plist_ref[-1]
        _plist_in = self._plist[:]
        _px = addPathToSearchPath(_addp, self._plist,**{'prepend':True,'redundant':False})
        assert _px == None
        self.assertEqual(_plist_in, self._plist)

    def test_UseCase021_append_try_same_again_nonredundant(self):
        """3. try to add same item again - with failure"""
        _addp = self._plist_ref[-1]
        _plist_in = self._plist[:]
        _px = addPathToSearchPath(_addp, self._plist,**{'append':True,'redundant':False})
        assert _px == None
        self.assertEqual(_plist_in, self._plist)

    def test_UseCase030_prepend_same_again_checkreal(self):
        """4. prepend same item again - with checkreal"""
        _addp = self._plist_ref[-1]
        _plist_in = self._plist[:]
        _plist_in.insert(0,os.path.realpath(_addp))
        _px = addPathToSearchPath(_addp, self._plist,**{'prepend':True,'redundant':True,'checkreal':True,})
        assert _px == 0
        assert _plist_in == self._plist 

    def test_UseCase040_delete_same(self):
        """5. remove the item"""
        _addp = self._plist_ref[-1]
        delPathFromSearchPath(_addp, self._plist)
        assert self._plist_ref[:-1] == self._plist 


    
#
#######################
#

if __name__ == '__main__':
    unittest.main()




"""Use-Cases: Search by literals + globs + regexpr

Find a matching relative filepathname in upper directory
tree for a given name/relative path containing literals, 
globs, and regexpr components. 

**Example**:

See testdata/findnodes

Calls::
    
    getTopFromPathString
    setUpperTreeSearchPath
    findRelPathInSearchPath

"""


"""Use-Cases: Search by literal names

Find a matching relative filepathname in upper directory
tree for a given name/relative path. 

**Example**:

See testdata/findnodes

Calls::
    
    getTopFromPathString
    setUpperTreeSearchPath
    findRelPathInSearchPath


"""


"""Searches for a pattern in paths from a provided list of strings.

Searches for a given path component by various constraints
on each string of provided 'plist' until the match of a break 
condition. The match is performed by default left-to-right, which 
results in top-down scan of a path hierarchy, or right-to-left as 
an upward bottom-up search.
    
Performs string operations only, the file system is neither
checked, not utilized.  
"""


from __future__ import absolute_import
from linecache import getline

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,platform
import tests.CheckEscUnesc

from filesysobjects.FileSysObjects import normpathX
#
#######################
#


class CallUnits(tests.CheckEscUnesc.CheckEscUnesc):

    def testCase112(self):
        _in        = r'file:///./file_at_current_dir'
        _esc     = r'file:///file_at_current_dir'
        _unesc = r'file:///file_at_current_dir'
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase122(self):
        _in        = r'file://////////////////////////.//file_at_current_dir'
        _esc     = r'file:///file_at_current_dir'
        _unesc = r'file:///file_at_current_dir'
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase300(self):
        _in        = r'./file_at_current_dir'
        _esc     = r'file_at_current_dir'
        _unesc = r'file_at_current_dir'
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase301(self):
        _in        = r'./////////////////file_at_current_dir'
        _esc     = r'file_at_current_dir'
        _unesc = r'file_at_current_dir'
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase400(self):
        _in        = r'file://./file_at_current_dir'
        _esc     = r'file://file_at_current_dir'
        _unesc = r'file://file_at_current_dir'
        self.check_esc_unesc(_in,_esc,_unesc, 's')
  
    def testCase401(self):
        _in        = r'file://././././././././././file_at_current_dir'
        _esc     = r'file://file_at_current_dir'
        _unesc = r'file://file_at_current_dir'
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase402(self):
        _in        = r'file://././././file_at_current_dir/././././.'
        _esc     = r'file://file_at_current_dir'
        _unesc = r'file://file_at_current_dir'
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase403(self):
        _in        = r'file://x/file_at_current_dir/..'
        _esc     = r'file://x'
        _unesc = 'file://x'
        self.check_esc_unesc(_in,_esc,_unesc, 's')
  
    def testCase404(self):
        _in        = r'file://file_at_current_dir/..'
        _esc     = r'file://'
        _unesc = 'file://'
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase409(self):
        _in        = r'file:///file_at_current_dir/../a/b/c/..'
        _esc     = r'file:///a/b'
        _unesc = r'file:///a/b'
        self.check_esc_unesc(_in,_esc,_unesc, 's')
  
    def testCase410(self):
        _in        = r'file:///file_at_current_dir/../a/b/c/../d/../e/../f/./g///////./././////.'
        _esc     = r'file:///a/b/f/g'
        _unesc = r'file:///a/b/f/g'
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase411(self):
        _in        = r'file://./././file_at_current_dir/././/a//././b/././'
        _esc     = r'file://file_at_current_dir/a/b'
        _unesc = r'file://file_at_current_dir/a/b'
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase500(self):
        _in        = r'file://./file_at_current_dir/a/b/'
        _esc     = r'file://file_at_current_dir/a/b'
        _unesc = r'file://file_at_current_dir/a/b'
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase501(self):
        _in        = r'file://./file_at_current_dir/a/../b'
        _esc     = r'file://file_at_current_dir/b'
        _unesc = r'file://file_at_current_dir/b'
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase510(self):
        _in        = r'file://./file_at_current_dir/a/b/..'
        _esc     = r'file://file_at_current_dir/a'
        _unesc = r'file://file_at_current_dir/a'
        self.check_esc_unesc(_in,_esc,_unesc, 's')


#
#######################
#

if __name__ == '__main__':
    unittest.main()




"""Check the expansion of 'sys.path' by PATH components derived from splice of upper tree.
"""
from __future__ import absolute_import

import unittest
import os,sys

from filesysobjects.FileSysObjects import setUpperTreeSearchPath


#
#######################
#
class UseCase(unittest.TestCase):
    

    
    

    #
    # Create by object
    #
    def testCase000(self):
        _s = sys.path[:]

        A = os.path.normpath('a/A.txt')         #@UnusedVariable
        B = os.path.normpath('a/b/B.txt')       #@UnusedVariable
        C = os.path.normpath('a/b/c/C.txt')     #@UnusedVariable
        D = os.path.normpath('a/b/c/d/D.txt')   #@UnusedVariable

        top = os.path.normpath(os.path.abspath(os.path.dirname(__file__)))  #@UnusedVariable
        start = top+os.sep+A

        res = []
        ret = setUpperTreeSearchPath(start,top,res) #@UnusedVariable
        
        resx = [
            os.path.normpath(os.path.dirname(top+os.sep+A)),
            top,
        ]

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        

        assert resx == res
        pass

    def testCase001(self):
        _s = sys.path[:]

        A = os.path.normpath('a/A.txt')         #@UnusedVariable
        B = os.path.normpath('a/b/B.txt')       #@UnusedVariable
        C = os.path.normpath('a/b/c/C.txt')     #@UnusedVariable
        D = os.path.normpath('a/b/c/d/D.txt')   #@UnusedVariable

        top = os.path.normpath(os.path.abspath(os.path.dirname(__file__)))
        start = top+os.sep+B

        res = []
        ret = setUpperTreeSearchPath(start,top,res) #@UnusedVariable
        
        resx = [
            os.path.normpath(os.path.dirname(top+os.sep+B)),
            top,
        ]
        resx.insert(1,os.path.normpath(os.path.dirname(resx[0][:-1])))

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        

        assert resx == res
        pass

    def testCase002(self):
        _s = sys.path[:]

        A = os.path.normpath('a/A.txt')         #@UnusedVariable
        B = os.path.normpath('a/b/B.txt')       #@UnusedVariable
        C = os.path.normpath('a/b/c/C.txt')     #@UnusedVariable
        D = os.path.normpath('a/b/c/d/D.txt')   #@UnusedVariable

        top = os.path.normpath(os.path.abspath(os.path.dirname(__file__)))
        start = top+os.sep+C

        res = []
        ret = setUpperTreeSearchPath(start,top,res) #@UnusedVariable
        
        resx = [
            os.path.normpath(os.path.dirname(top+os.sep+C)),
            top,
        ]
        resx.insert(1,os.path.normpath(os.path.dirname(resx[0][:-1])))
        resx.insert(2,os.path.normpath(os.path.dirname(resx[1][:-1])))

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        

        assert resx == res
        pass

    def testCase003(self):
        _s = sys.path[:]

        A = os.path.normpath('a/A.txt')         #@UnusedVariable
        B = os.path.normpath('a/b/B.txt')       #@UnusedVariable
        C = os.path.normpath('a/b/c/C.txt')     #@UnusedVariable
        D = os.path.normpath('a/b/c/d/D.txt')   #@UnusedVariable

        top = os.path.normpath(os.path.abspath(os.path.dirname(__file__)))
        start = top+os.sep+D

        res = []
        ret = setUpperTreeSearchPath(start,top,res) #@UnusedVariable
        
        resx = [
            os.path.normpath(os.path.dirname(top+os.sep+D)),
            top,
        ]
        resx.insert(1,os.path.normpath(os.path.dirname(resx[0][:-1])))
        resx.insert(2,os.path.normpath(os.path.dirname(resx[1][:-1])))
        resx.insert(3,os.path.normpath(os.path.dirname(resx[2][:-1])))

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        

        assert resx == res
        pass

if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import tests.CheckEscUnesc

#
#######################
#


class CallUnits(tests.CheckEscUnesc.CheckEscUnesc):
    
    def testCase_a0(self):
        _in        = '\a'
        _esc     = r'/a'
        _unesc = r'/a' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_b(self):
        _in        = '\b'
        _esc     = r'/b'
        _unesc = r'/b' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_c(self):
        _in        = '\c'
        _esc     = r'/c'
        _unesc = r'/c' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_d(self):
        _in        = '\d'
        _esc     = r'/d'
        _unesc = r'/d' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_e(self):
        _in        = '\e'
        _esc     = r'/e'
        _unesc = r'/e' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_f(self):
        _in        = '\f'
        _esc     = r'/f'
        _unesc = r'/f' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_g(self):
        _in        = '\g'
        _esc     = r'/g'
        _unesc = r'/g' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_h(self):
        _in        = '\h'
        _esc     = r'/h'
        _unesc = r'/h' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_i(self):
        _in        = '\i'
        _esc     = r'/i'
        _unesc = r'/i' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_j(self):
        _in        = '\j'
        _esc     = r'/j'
        _unesc = r'/j' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_k(self):
        _in        = '\k'
        _esc     = r'/k'
        _unesc = r'/k' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_l(self):
        _in        = '\l'
        _esc     = r'/l'
        _unesc = r'/l' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_m(self):
        _in        = '\m'
        _esc     = r'/m'
        _unesc = r'/m' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_n(self):
        _in        = '\n'
        _esc     = r'/n'
        _unesc = r'/n' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_o(self):
        _in        = '\r'
        _esc     = r'/r'
        _unesc = r'/r' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_p(self):
        _in        = '\p'
        _esc     = r'/p'
        _unesc = r'/p' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_q(self):
        _in        = '\q'
        _esc     = r'/q'
        _unesc = r'/q' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_r(self):
        _in        = '\r'
        _esc     = r'/r'
        _unesc = r'/r' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_s(self):
        _in        = '\s'
        _esc     = r'/s'
        _unesc = r'/s' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_t(self):
        _in        = '\t'
        _esc     = r'/t'
        _unesc = r'/t' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_u(self):
        _in        = '\u'
        _esc     = r'/u'
        _unesc = r'/u' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_v(self):
        _in        = '\v'
        _esc     = r'/v'
        _unesc = r'/v' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_w(self):
        _in        = '\w'
        _esc     = r'/w'
        _unesc = r'/w' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_x(self):
        _in        = '\\'+'x'
        _esc     = r'/x'
        _unesc = r'/x' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_y(self):
        _in        = '\y'
        _esc     = r'/y'
        _unesc = r'/y' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

    def testCase_z(self):
        _in        = '\z'
        _esc     = r'/z'
        _unesc = r'/z' 
        self.check_esc_unesc(_in,_esc,_unesc, 's')

#
#######################
#

if __name__ == '__main__':
    unittest.main()




"""Check search of a relative filepathname - side-branch - in upper tree.
"""
from __future__ import absolute_import
from __future__ import print_function

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

from filesysobjects.FileSysObjects import setUpperTreeSearchPath
from filesysobjects.FileSysObjects import findRelPathInSearchPath,addPathToSearchPath
from pysourceinfo.PySourceInfo import getPythonPathRel



#
#######################
#

class UseCase(unittest.TestCase):
    

    
    

    def testCase000(self):
        _s = sys.path[:]
        lst = []
        assert setUpperTreeSearchPath(os.path.abspath(os.path.dirname(__file__)+os.path.sep+'..'),'UseCases',lst)
        
        x  = os.path.abspath(os.path.dirname(__file__))+os.path.sep+"test"
        assert addPathToSearchPath(x,lst) >= 0
        
        epy = findRelPathInSearchPath('test00.d'+os.path.sep+'test01',lst,matchidx=0)
        epy = getPythonPathRel(epy,[os.path.abspath(os.path.dirname(__file__)+'../../../../..')])
        x = "UseCases"+os.path.sep+"FileSysObjects"+os.path.sep+"functions"+os.path.sep+"addPathToSearchPath"+os.path.sep+"test"+os.path.sep+"test00.d"+os.path.sep+"test01"
        assert epy == x

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        pass
 
#
#######################
#

if __name__ == '__main__':
    unittest.main()




from __future__ import absolute_import

#
#######################
#
class Dummy0:

    myName = "Dummy0"
    
    def __init__(self):
        pass

    def set(self,a):
        self.a = a

    def get(self):
        return self.myName+str(self.a)



"""Check IEEE1003.1-Chap. 4.2.
"""
from __future__ import absolute_import

import unittest
import os,sys

from pysourceinfo.PySourceInfo import getPythonPathRel
from filesysobjects.FileSysObjects import setUpperTreeSearchPath,getTopFromPathString,unescapeFilePath


#
#######################
#
class UseCase(unittest.TestCase):
    
    def testCase_simple_file_abs(self):
        _s = sys.path[:]
        start = os.path.abspath(os.path.dirname(__file__)+os.path.normpath('/a/b/c'))
        top = os.path.dirname(__file__)
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable

        myplist = [getTopFromPathString('AppPathSyntax',[os.path.dirname(__file__)+os.sep+start])]
        res = []
        for i in range(len(_res)):
            _p = getPythonPathRel(_res[i],myplist)
            if _p:
                res.append(_p) 
        resx = [
            'file/file_simple/a/b/c',
            'file/file_simple/a/b',
            'file/file_simple/a',
            'file/file_simple',
        ]
        resx = map(os.path.normpath,resx)

        res = map(unescapeFilePath, res)
        resx = map(unescapeFilePath, resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        assert resx == res
        pass


if __name__ == '__main__':
    unittest.main()



"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os,sys

from pysourceinfo.PySourceInfo import getPythonPathRel
from filesysobjects.FileSysObjects import setUpperTreeSearchPath


#
#######################
#
class CallUnits(unittest.TestCase):
    

    
    

    #
    # Create by object
    #
    def testCase000(self):
        """Check defaults.
        """
        _s = sys.path[:]

        start = os.path.dirname(__file__)+os.sep+'a'+os.sep+'b'+os.sep+'c'+os.sep+'d'+os.sep+'b'+os.sep+'c'+os.sep
        start = os.path.abspath(start)
        top = 'tests'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'reverse':True}) #@UnusedVariable
        
        mypos = os.path.abspath(os.path.normpath(os.path.dirname(__file__)+"/../../"))   
        res = []
        for i in range(len(_res)):
            pr = getPythonPathRel(_res[i],[mypos])
            if pr:
                res.append(pr)
        resx = [
            '.', 
            '300_reverse', 
            '300_reverse/Case030', 
            '300_reverse/Case030/a', 
            '300_reverse/Case030/a/b', 
            '300_reverse/Case030/a/b/c', 
            '300_reverse/Case030/a/b/c/d', 
            '300_reverse/Case030/a/b/c/d/b', 
            '300_reverse/Case030/a/b/c/d/b/c'
        ]
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert resx == res
        pass

if __name__ == '__main__':
    unittest.main()



"""Use-Cases as PyUnit tests

These tests could either be called from the command line,
or within Eclipse by the plugin PyDev / PyUnit.
'setup.py' also supports the call by the parameter 'usecases'.

* setup.py: '*python setup.py usecases*'

* CLI: '*python -m unittest discover -s UseCases -p CallCase.py*' 

* Eclipse: Install PyDev, open the view PyUnit and proceed by
  'UseCases' package.

"""
__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2015-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.1.0'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__package__ = 'filesysobjects_pyunit'



from __future__ import absolute_import
from __future__ import print_function
from linecache import getline

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

import filesysobjects.FileSysObjects
import pysourceinfo.PySourceInfo

#
#######################
#


class CallUnits(unittest.TestCase):
    
    def __init__(self,*args,**kargs):
        """Creates search path list
        """
        super(CallUnits,self).__init__(*args,**kargs)    

        self._s = sys.path[:]

        # data
        import testdata
        self.myBase = testdata.mypath+os.sep+"findnodes"

        #
        # prefix from unchanged sys.path
        self.mySysPathPrefixRaw = pysourceinfo.PySourceInfo.getPythonPathFromSysPath(__file__) #@UnusedVariable
        
        self.myTestPath0Rel = os.path.normpath('a/b/c/d/e/f/g/h')
        self.myTestPath1Rel = self.myTestPath0Rel +os.sep+ self.myTestPath0Rel
        self.myTestPath2Rel = self.myTestPath1Rel +os.sep+ self.myTestPath0Rel
        self.myTestPath3Rel = self.myTestPath2Rel +os.sep+ self.myTestPath0Rel
        self.myTestPath4Rel = self.myTestPath3Rel +os.sep+ self.myTestPath0Rel
        
        
        self.myTestPath0 = self.myBase+os.sep+self.myTestPath0Rel #@UnusedVariable
        self.myTestPath1 = self.myBase+os.sep+self.myTestPath1Rel #@UnusedVariable
        self.myTestPath2 = self.myBase+os.sep+self.myTestPath2Rel #@UnusedVariable
        self.myTestPath3 = self.myBase+os.sep+self.myTestPath3Rel #@UnusedVariable
        self.myTestPath4 = self.myBase+os.sep+self.myTestPath4Rel #@UnusedVariable

    def reset_sys_path(self):
        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(self._s)

    def testCase000(self):

        rpath = self.myTestPath1[-1:]
        plistRaw = [
            self.myTestPath0,
            self.myTestPath1,
            self.myTestPath3+os.pathsep+self.myTestPath2+os.pathsep+self.myTestPath2+os.pathsep+self.myTestPath2+os.pathsep+self.myTestPath2,
            self.myTestPath3,
        ]        
        filesysobjects.FileSysObjects.clearPath(plistRaw,**{'redundant':True,'shrink':True,'split':True}) # here just a demo
        plist = [
            self.myTestPath0,
            self.myTestPath1,
            self.myTestPath3,
            self.myTestPath2,
        ]        
        assert plist == plistRaw

        kargs = {'matchlvl':3}
        px = []
        for ix in filesysobjects.FileSysObjects.getTopFromPathStringIter(rpath, plist,**kargs):
            px.append(ix)
        
        pxn = [
            self.myTestPath3,
        ]

        
        self.reset_sys_path()

        assert px == pxn 
        pass


#
#######################
#

if __name__ == '__main__':
    unittest.main()




from __future__ import absolute_import
from linecache import getline


__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os
import tests.CheckNormpathX

import filesysobjects.FileSysObjects

#
#######################
#

class CallUnits(tests.CheckNormpathX.CheckNormpathX):
    
    def testCase001(self):
#        _in = '//hostname/tests//////a/b/hostname//c////////d/tests/b///c'
        _in = r'\\hostname\tests\a/b/hostname/c/d/tests/b/c'
        _norm = r'\\hostname\tests\a/b/hostname/c/d/tests/b/c'
        self.check_normpathX(_in,_norm,'keep')

    def testCase002(self):
        _in = 'hostname////////////'
        _norm = os.path.normpath(r'hostname')
        self.check_normpathX(_in,_norm)

    def testCase003(self):
        _in = '//hostname/tests/a/b/hostname'
        _norm = os.path.normpath(r'//hostname/tests/a/b/hostname')
        self.check_normpathX(_in,_norm)




#
#######################
#

if __name__ == '__main__':
    unittest.main()




from __future__ import absolute_import
from linecache import getline


__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

import filesysobjects.FileSysObjects
import pysourceinfo.PySourceInfo

#
#######################
#


class CallUnits(unittest.TestCase):

    def testCase000(self):

        start = os.path.dirname(__file__)+os.sep+'a/tests//////a/b/tests//c////////d/tests/b///c'
        #top = '/////tests///'
        top = 'tests///'
        top = filesysobjects.FileSysObjects.getTopFromPathString(top, [start]) #@UnusedVariable
        top0ref=os.path.abspath(os.path.dirname(__file__)+'/../../../../../')

        self.assertEqual(top0ref, os.path.abspath(top)) 
        pass


#
#######################
#

if __name__ == '__main__':
    unittest.main()




"""Create a plist, find a matching relative filepathname in directory tree.

Calling elementary functions.

* **Data**:
  ::
  
    see 'testdata.examples'
  
  refer also to the manual `[filesystem-elements-as-objects] <path_syntax.html#filesystem-elements-as-objects>`_

* **Call**:
  ::

    # 1. make it canonical - optional, here just a demo
    clearPath(_plist,**{'redundant':True,'shrink':True})
    
* **Result**:
  ::

    expected = os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0/F1')

"""
from __future__ import absolute_import
from __future__ import print_function
import filesysobjects

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

from filesysobjects.FileSysObjects import setUpperTreeSearchPath
from filesysobjects.FileSysObjects import findRelPathInSearchPath
from filesysobjects.FileSysObjects import clearPath

#
#######################
#

class UseCase(unittest.TestCase):
    
    def testCase000(self):
        _s = sys.path[:]

        import testdata
        import filesysobjects.FileSysObjects
          
        s = os.sep
        
        # start of upward search - file is converted into it's containing directory node
        any_sub_path = os.path.normpath('examples/a/b0/c/a/b0/c/F')
        spath  = testdata.mypath
        spath += s+ any_sub_path

        # check environment
        assert os.path.exists(spath)
                
        # store new search list, here without required sys.path
        _plist = []


        # 0. build a search path list - if not yet available
        #    adds each directory from spath to its matching 
        #    subnode  "a/b"
        #
        setUpperTreeSearchPath(spath,os.path.normpath('a/b0'), _plist)
        _plist_ref = [ # expected plist
            os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0/c'),
            os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0'),
            os.path.normpath(testdata.mypath+'/examples/a/b0/c/a'),
            os.path.normpath(testdata.mypath+'/examples/a/b0/c'),
            os.path.normpath(testdata.mypath+'/examples/a/b0'),
        ]
        assert _plist_ref == _plist 

        # 1. make it canonical - optional, here just a demo
        _chk_ref = _plist[:]
        _plist.extend(_plist[:]) # duplicate all for demonstration
        assert _plist != _chk_ref
        clearPath(_plist,**{'redundant':True,'shrink':True}) # and clear them immediately
        assert _plist == _chk_ref

        # 2.a. find the requested entry
        rp = findRelPathInSearchPath("F[0-5]*",_plist)
        expected = os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0/F1')
        assert expected == rp 

        # 2.b. find the requested entry - here as demo with a relative path
        rp = findRelPathInSearchPath("c/*/b0/F[0-5]*",_plist)
        expected = os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0/F1')
        assert expected == rp 

    
#
#######################
#

if __name__ == '__main__':
    unittest.main()




"""Create a plist, find side branches with single and multi-node hooks.

* **Data**:
  ::
  
    see 'testdata.examples'
  
  refer also to the manual `[filesystem-elements-as-objects] <path_syntax.html#filesystem-elements-as-objects>`_

* **Call**:
  ::

    # 1. search and create a path for a side branch - single node hook
    sp = os.path.normpath('a/new/branch')
    rp = getTopFromPathString(sp,self._plist)

    # 2. search and create a path for a side branch by a multipoint hook as a slice
    sp = os.path.normpath('c/a/new/branch')
    rp = getTopFromPathString(sp,self._plist)


* **Result**:
  ::

    1. expected = os.path.normpath(testdata.mypath+'/examples/a/new/branch')
    2. expected = os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/new/branch')

"""
from __future__ import absolute_import
from __future__ import print_function
import filesysobjects

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

from filesysobjects.FileSysObjects import setUpperTreeSearchPath
from filesysobjects.FileSysObjects import findRelPathInSearchPath
from filesysobjects.FileSysObjects import getTopFromPathString

#
#######################
#

class UseCase(unittest.TestCase):
    
    def __init__(self,*args,**kargs):
        """Initialize common refence and data"""
        
        super(UseCase,self).__init__(*args,**kargs)
        
        _s = sys.path[:]

        import testdata
          
        s = os.sep
        
        # start of upward search - file is converted into it's containing directory node
        any_sub_path = os.path.normpath('examples/a/b0/c/a/b0/c/F')
        spath  = testdata.mypath
        spath += s+ any_sub_path

        # check environment
        assert os.path.exists(spath)
                
        # store new search list, here without required sys.path
        self._plist = []


        # 0. build a search path list - if not yet available
        #    adds each directory from spath to its matching 
        #    subnode  "a/b"
        #
        setUpperTreeSearchPath(spath,os.path.normpath('a/b0'), self._plist)
        self._plist_ref = [ # expected plist
            os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0/c'),
            os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/b0'),
            os.path.normpath(testdata.mypath+'/examples/a/b0/c/a'),
            os.path.normpath(testdata.mypath+'/examples/a/b0/c'),
            os.path.normpath(testdata.mypath+'/examples/a/b0'),
        ]
        assert self._plist_ref == self._plist 


    def testCase001(self):
        """1. search and create a path for a side branch by a single point hook"""
        import testdata

        sp = os.path.normpath('a/new/branch')
        expected = os.path.normpath(testdata.mypath+'/examples/a/new/branch')
        rp = getTopFromPathString(sp,self._plist)
        assert expected == rp 

    def testCase002(self):
        """1. search and create a path for a side branch by a multipoint hook as a slice"""
        import testdata

        sp = os.path.normpath('c/a/new/branch')
        expected = os.path.normpath(testdata.mypath+'/examples/a/b0/c/a/new/branch')
        rp = getTopFromPathString(sp,self._plist)
        assert expected == rp 


#
#######################
#

if __name__ == '__main__':
    unittest.main()




from __future__ import absolute_import
from linecache import getline


__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

import filesysobjects.FileSysObjects

#
#######################
#


class UseCase(unittest.TestCase):

    def testCase_uri_smb(self):
        apstr = 'smb://'+os.path.normpath('hostname/share/a/b/c')
        retRef = ('SMB','hostname', 'share', os.path.normpath('a/b/c')) 
        ret = filesysobjects.FileSysObjects.splitAppPrefix(apstr)
        self.assertEqual(retRef, ret) 



#
#######################
#

if __name__ == '__main__':
    unittest.main()




from __future__ import absolute_import

import unittest
import os,sys

from filesysobjects.FileSysObjects import setUpperTreeSearchPath,addPathToSearchPath,unescapeFilePath

#
#######################
#
class CallUnits(unittest.TestCase):
    
    def testCase000(self):
        _s = sys.path[:]

        A = os.path.normpath('a/A.txt')         #@UnusedVariable
        B = os.path.normpath('a/b/B.txt')       #@UnusedVariable
        C = os.path.normpath('a/b/c/C.txt')     #@UnusedVariable
        D = os.path.normpath('a/b/c/d/D.txt')   #@UnusedVariable

        start = os.path.abspath(os.path.dirname(__file__))
        top = start
        res = []
        ret = setUpperTreeSearchPath(start,top,res) #@UnusedVariable
        
        addPathToSearchPath(os.path.dirname(os.path.dirname(__file__)+os.sep+C), res)
        
        resx = [
            os.path.dirname(os.path.dirname(__file__)+os.sep+C),
            os.path.abspath(os.path.dirname(__file__)),
        ]

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        res = map(unescapeFilePath, res)
        resx = map(unescapeFilePath, resx)

        assert resx == res
        pass

if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import
from __future__ import print_function

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.1.4'
__uuid__='9de52399-7752-4633-9fdc-66c87a9200b8'

__docformat__ = "restructuredtext en"

import unittest
import sys,os
    
import testdata

from filesysobjects.FileSysObjects import setUpperTreeSearchPath,findRelPathInSearchPath
from filesysobjects.FileSysObjects import normpathX
from filesysobjects.FileSysObjects import getTopFromPathString

#
#######################
#

class UseCase(unittest.TestCase):
    def testCase000(self):

        # *** save sys.path ***
        _s = sys.path[:]
        # *********************

        # set search for the call of 'myscript.sh'
        setUpperTreeSearchPath(None,'filesysobjects')

        _start = testdata.mypath + '/findnodes/a/b/c/d/e/f/g/h/a/b/c/d/e/f/g/h/a/b/c/d/e/f/g/h'
        _start = normpathX(_start)
        _top = "a/b/x/y/data"
        _top = normpathX(_top)
        _tlst = []
        
        # 0. get top node within-start/path, this is eventually base on a part of the 
        #    search path, gets the topmost hook by default.
        _top = "a/b/.*/[def]{1}/da*"
        _top = normpathX(_top)
        topX = getTopFromPathString(_top, [_start],**{'hook':True,'pattern':'regnode',})
        topXs = getTopFromPathString(_top, [_start],**{'split':True,'pattern':'regnode',})
        topx = getTopFromPathString(_top, [_start],**{'pattern':'regnode',})
        
        # 1. set the search list 
        t = setUpperTreeSearchPath(_start, topX, _tlst)
        if t:
            # 2. search side branch
            a0 = findRelPathInSearchPath(
                topx,
                _tlst,
                **{'reverse':True,'matchidx':0}
            )


        # *** restore sys.path ***
        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        # ************************
        
        assert a0.endswith(normpathX("findnodes/a/b/c/d/data"))
        assert a0.endswith(os.path.normpath("findnodes/a/b/c/d/data"))
        
        pass

#
#######################
#

if __name__ == '__main__':
    unittest.main()




"""Check defaults.
"""
from __future__ import absolute_import

import unittest
import os,sys

from pysourceinfo.PySourceInfo import getPythonPathRel
from filesysobjects.FileSysObjects import setUpperTreeSearchPath,\
    FileSysObjectsException,getTopFromPathString


#
#######################
#
class CallUnits(unittest.TestCase):

    def testCase000(self):
        _s = sys.path[:]
        start = os.path.normpath(os.path.dirname(__file__)+os.sep+'a/tests//////a/b/tests//c////////d/tests/b///c')
        start = os.path.abspath(start)
        
        top = os.path.normpath('tests///')
        top = getTopFromPathString(top,[start])

        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'matchlvl':0,'ias':True}) #@UnusedVariable
                
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathRel(_res[i],[top]))
            
        resx = [
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/220_matchcnt/Case040/a/tests/a/b/tests/c/d/tests/b/c',
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/220_matchcnt/Case040/a/tests/a/b/tests/c/d/tests/b', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/220_matchcnt/Case040/a/tests/a/b/tests/c/d/tests', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/220_matchcnt/Case040/a/tests/a/b/tests/c/d', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/220_matchcnt/Case040/a/tests/a/b/tests/c', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/220_matchcnt/Case040/a/tests/a/b/tests', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/220_matchcnt/Case040/a/tests/a/b', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/220_matchcnt/Case040/a/tests/a', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/220_matchcnt/Case040/a/tests', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/220_matchcnt/Case040/a', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/220_matchcnt/Case040', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/220_matchcnt', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath', 
            '30_libs/040_FileSysObjects', 
            '30_libs', 
            '', 
        ]
        resx = map(os.path.normpath, resx)
        res = map(os.path.normpath, res)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
                
        assert resx == res
        pass

    def testCase000r(self):
        _s = sys.path[:]

        start = os.path.normpath(os.path.dirname(__file__)+os.sep+'a/tests//////a/b/tests//c////////d/tests/b///c')
        start = os.path.abspath(start)

        top = os.path.normpath('tests///')
        top = getTopFromPathString(top, [start]) #@UnusedVariable


        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'matchlvl':0,'reverse':True,'ias':True}) #@UnusedVariable

        mypos = os.path.abspath(os.path.normpath(os.path.dirname(__file__)+"/../"))   
        res = []
        for i in range(len(_res)):
            pr = getPythonPathRel(_res[i],[mypos])
            if pr:
                res.append(pr)
        
        resx = [
            '.', 
            'Case040', 
            'Case040/a', 
            'Case040/a/tests', 
            'Case040/a/tests/a', 
            'Case040/a/tests/a/b', 
            'Case040/a/tests/a/b/tests', 
            'Case040/a/tests/a/b/tests/c', 
            'Case040/a/tests/a/b/tests/c/d', 
            'Case040/a/tests/a/b/tests/c/d/tests', 
            'Case040/a/tests/a/b/tests/c/d/tests/b', 
            'Case040/a/tests/a/b/tests/c/d/tests/b/c'
        ]

        res = map(os.path.normpath, res)
        resx = map(os.path.normpath, resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        self.assertEqual(resx ,res) 
        pass

    def testCase001(self):
        _s = sys.path[:]
        start = os.path.normpath(os.path.dirname(__file__)+os.sep+'a/tests/a/b/tests/c/d/tests/b/c')
        start = os.path.abspath(start)
        
        top = os.path.normpath('tests')
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'matchlvl':1,'reverse':True,'ias':True}) #@UnusedVariable
        
        mypos = os.path.abspath(os.path.normpath(os.path.dirname(__file__)+"/../"))   
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathRel(_res[i],[mypos]))
            
        resx = [
            'Case040/a/tests', 
            'Case040/a/tests/a', 
            'Case040/a/tests/a/b',
            'Case040/a/tests/a/b/tests', 
            'Case040/a/tests/a/b/tests/c', 
            'Case040/a/tests/a/b/tests/c/d', 
            'Case040/a/tests/a/b/tests/c/d/tests', 
            'Case040/a/tests/a/b/tests/c/d/tests/b', 
            'Case040/a/tests/a/b/tests/c/d/tests/b/c'
        ]

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        resx = map(os.path.abspath, resx)
        res = map(os.path.abspath, res)

        assert resx == res
        pass

    def testCase002(self):
        _s = sys.path[:]
        start = os.path.normpath(os.path.dirname(__file__)+os.sep+'a/tests/a/b/tests/c/d/tests/b/c')
        start = os.path.abspath(start)
        
        top = os.path.normpath('tests')
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'matchlvl':2,'reverse':True,'ias':True}) #@UnusedVariable

        mypos = os.path.abspath(os.path.normpath(os.path.dirname(__file__)+"/../"))   
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathRel(_res[i],[mypos]))
            
        resx = [
            'Case040/a/tests/a/b/tests', 
            'Case040/a/tests/a/b/tests/c', 
            'Case040/a/tests/a/b/tests/c/d', 
            'Case040/a/tests/a/b/tests/c/d/tests', 
            'Case040/a/tests/a/b/tests/c/d/tests/b', 
            'Case040/a/tests/a/b/tests/c/d/tests/b/c'
        ]
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        resx = map(os.path.abspath, resx)
        res = map(os.path.abspath, res)
        
        assert resx == res
        pass


    def testCase005(self):
        _s = sys.path[:]
        start = os.path.normpath(os.path.dirname(__file__)+os.sep+'a/tests/a/b/tests/c/d/tests/b/c')
        start = os.path.abspath(start)
        
        top = os.path.normpath('tests')
        _res = []
        try:
            ret = setUpperTreeSearchPath(start,top,_res,**{'matchlvl':5,'ias':True}) #@UnusedVariable
        except FileSysObjectsException as e: #@UnusedVariable
            pass
        else:
            assert False
        pass

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        


if __name__ == '__main__':
    unittest.main()



"""Check IEEE1003.1-Chap. 4.2.
"""
from __future__ import absolute_import

import unittest
import os,sys
import platform

from pysourceinfo.PySourceInfo import getPythonPathRel,getPythonPathFromSysPath
from filesysobjects.FileSysObjects import setUpperTreeSearchPath,FileSysObjectsException,splitAppPrefix,getAppPrefixLocalPath,getTopFromPathString,unescapeFilePath
from unittest.case import SkipTest


#
#######################
#
class CallUnits(unittest.TestCase):
    
    def testCase000(self):
        _s = sys.path[:]
        start = os.path.abspath(os.path.dirname(__file__))+os.path.normpath('/a/b/c')
        top = os.path.abspath(os.path.dirname(__file__))
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable

        myplist = [getTopFromPathString('tests',[os.path.dirname(__file__)+os.sep+start])]
        res = []
        for i in range(len(_res)):
            _p = getPythonPathRel(_res[i],myplist)
            if _p:
                res.append(_p) 
        resx = [
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b/c', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a',
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020',
        ]        
        resx = map(os.path.normpath,resx)

        res = map(unescapeFilePath, res)
        resx = map(unescapeFilePath, resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        assert resx == res
        pass

    def testCase001(self):

        _s = sys.path[:]
        
        start0 = os.path.abspath(os.path.dirname(__file__)+os.sep+os.path.normpath('/a/b/c'))
        d,p = os.path.splitdrive(start0)
        start1 = os.sep + p
    
        # normalize
        _start_elems = splitAppPrefix(start0,**{'ias':True})
        start= getAppPrefixLocalPath(_start_elems)

        assert start0 == start
        
        top = 'tests/'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'ias':True}) #@UnusedVariable

        myplist = [getTopFromPathString('tests',[start])]
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathRel(_res[i],myplist)) 
        resx = [
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b/c', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a',
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020',
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003',
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath',
            '30_libs/040_FileSysObjects',
            '30_libs',
            '.',
        ]        
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        assert resx == res
        pass

    def testCase002(self):

        _s = sys.path[:]
        
        start0 = os.path.abspath(os.path.dirname(__file__)+os.sep+os.path.normpath('/a/b/c'))
        d,p = os.path.splitdrive(start0)
        start1 = os.sep + p
    
        # normalize
        _start_elems = splitAppPrefix(start0,**{'ias':True})
        start= getAppPrefixLocalPath(_start_elems)

        assert start0 == start
        
        top = 'tests/'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'ias':True}) #@UnusedVariable

        myplist = [getTopFromPathString('tests',[start])]
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathRel(_res[i],myplist)) 
        resx = [
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b/c', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a',
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020',
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003',
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath',
            '30_libs/040_FileSysObjects',
            '30_libs',
            '.',
        ]        
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        assert resx == res
        pass

    def testCase010(self):

        #for now windows only
        #for now windows only
        if platform.system() != 'Windows':
            unittest.SkipTest("Requires Windows - skipped!")
            return True
        
        _s = sys.path[:]

        start0 = os.path.abspath(os.path.dirname(__file__)+os.sep+os.path.normpath('/a/b/c'))
        start1 = os.sep + start0
    
        # normalize
        _start_elems = splitAppPrefix(start0,**{'ias':True})
        start= getAppPrefixLocalPath(_start_elems)

        assert start0 == start

        top = 'file://'+os.path.splitdrive(os.path.abspath(os.path.dirname(__file__)))[1]

        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'ias':True}) #@UnusedVariable
        
        forDebugOnly = sys.path #@UnusedVariable
        
        myplist = [getTopFromPathString('tests',[start])]
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathRel(_res[i],myplist)) 

        resx = [
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b/c', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a',
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020',
        ]
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        assert resx == res
        pass

    def testCase012(self):

        if platform.system() != 'Windows':
            unittest.SkipTest("Requires Windows - skipped!")
            return True
       
        _s = sys.path[:]

        _share,start = os.path.splitdrive(os.path.abspath(os.path.dirname(__file__))+os.path.normpath('/a/b/c'))
        _share,top = os.path.splitdrive(os.path.abspath(os.path.dirname(__file__))+os.path.normpath('/a'))
        top = 'file://'+top
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'ias':True}) #@UnusedVariable
        
        forDebugOnly = sys.path #@UnusedVariable
        
        myplist = [getTopFromPathString('tests',[start])]
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathRel(_res[i],myplist)) 

        resx = [
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b/c', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a'
        ]
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        

        assert resx == res
        pass

    def testCase013(self):

        if platform.system() != 'Windows':
            unittest.SkipTest("Requires Windows - skipped!")
            return True
        if not os.path.exists('\\\\localhost\\C$'):
            unittest.SkipTest("Requires share for this test - skipped!")
            return True
        
        _s = sys.path[:]

        _rtype = 'SHARE'
        _host = 'localhost'
        _share,sp = os.path.splitdrive(os.path.abspath(os.path.dirname(__file__))+os.path.normpath('/a/b/c'))
        _share = 'C$'
        start = getAppPrefixLocalPath((_rtype, _host, _share,sp,))

        _share,top = os.path.splitdrive(os.path.abspath(os.path.dirname(__file__))+os.path.normpath('/a'))
        top = 'file://'+top[1:]
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable
        
        forDebugOnly = sys.path #@UnusedVariable
        
        myplist_elems = splitAppPrefix(start)
        myplist = [getTopFromPathString('tests',[start])]
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathRel(_res[i],myplist)) 

        resx = [
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b/c', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b', 
            '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a'
        ]
        resx = map(os.path.normpath,resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        

        assert resx == res
        pass

#TODO:
#     def testCase015(self):
# 
#         #for now windows only
#         if platform.system() != 'Windows':
#             unittest.SkipTest("Requires Windows - skipped!")
#             return True
#         
#         _s = sys.path[:]
# 
#         start0 = os.path.abspath(os.path.dirname(__file__)+os.sep+os.path.normpath('/a/b/c'))
#         start1 = os.sep + start0
#     
#         # normalize
#         _start_elems = splitAppPrefix(start0,**{'ias':True})
#         start= getAppPrefixLocalPath(_start_elems)
# 
#         assert start0 == start
# 
#         top = 'file://'+os.sep+os.path.splitdrive(os.path.abspath(os.path.dirname(__file__)))[1]
# 
#         _res = []
#         ret = setUpperTreeSearchPath(start,top,_res,**{'ias':True}) #@UnusedVariable
#         
#         forDebugOnly = sys.path #@UnusedVariable
#         
#         myplist = [getTopFromPathString('tests',[start])]
#         res = []
#         for i in range(len(_res)):
#             res.append(getPythonPathRel(_res[i],myplist)) 
# 
#         resx = [
#             '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b/c', 
#             '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a/b', 
#             '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/800_ieee1003/Case020/a'
#         ]
#         resx = map(os.path.normpath,resx)
# 
#         [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
#         sys.path.extend(_s)
        

        assert resx == res
        pass


if __name__ == '__main__':
    unittest.main()



"""Check error condition.
"""
from __future__ import absolute_import

import unittest
import os,sys

from filesysobjects.FileSysObjects import setUpperTreeSearchPath,FileSysObjectsException


#
#######################
#
class CallUnits(unittest.TestCase):
    

    
    

    #
    # Create by object
    #
    def testCase000(self):
        """Check error condition.
        """
        _s = sys.path[:]
        A = os.path.normpath('a/A.txt')        #@UnusedVariable
        B = os.path.normpath('a/b/B.txt')      #@UnusedVariable
        C = os.path.normpath('a/b/c/C.txt')    #@UnusedVariable
        D = os.path.normpath('a/b/c/d/D.txt')  #@UnusedVariable

        start = None
        top = ''
        res = []
        try:
            ret = setUpperTreeSearchPath(start,top,res) #@UnusedVariable
        except FileSysObjectsException:
            pass
        else:
            raise
        pass

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        

    def testCase001(self):
        """Check error condition.
        """
        _s = sys.path[:]
        A = os.path.normpath('a/A.txt')        #@UnusedVariable
        B = os.path.normpath('a/b/B.txt')      #@UnusedVariable
        C = os.path.normpath('a/b/c/C.txt')    #@UnusedVariable
        D = os.path.normpath('a/b/c/d/D.txt')  #@UnusedVariable

        start = ''
        top = None
        res = []
        try:
            ret = setUpperTreeSearchPath(start,top,res) #@UnusedVariable
        except FileSysObjectsException:
            pass
        else:
            raise
        pass

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        

if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import
from __future__ import print_function
from linecache import getline

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

import filesysobjects.FileSysObjects
import pysourceinfo.PySourceInfo

#
#######################
#


class CallUnits(unittest.TestCase):

    def testCase000(self):

        p0 = os.path.normpath('a0/b')
        p1 = os.path.normpath('a0/b/a1/b')
        p2 = os.path.normpath('a0/b/a1/b/a2/b')
        p3 = os.path.normpath('a0/b/a1/b/a2/b/a3/b')

        rpath = os.path.normpath('b/')
        plistRaw = [
            p3,
        ]
        plist = plistRaw[:]
        filesysobjects.FileSysObjects.clearPath(plist,**{'redundant':True,'shrink':True,'split':True}) # here just a demo
        plistRef = [
            p3,
        ]        
        assert plist == plistRef

        kargs = {'matchlvl':2}
        px = []
        for ix in filesysobjects.FileSysObjects.getTopFromPathStringIter(rpath, plist,**kargs):
            px.append(os.path.normpath(ix))
        
        pxn = [
            p2,
        ]

        assert px == pxn 
        pass


#
#######################
#

if __name__ == '__main__':
    unittest.main()




"""Check IEEE1003.1-Chap. 4.2.
"""
from __future__ import absolute_import

import unittest
import os,sys

from pysourceinfo.PySourceInfo import getPythonPathRel
from filesysobjects.FileSysObjects import setUpperTreeSearchPath,normpathX


#
#######################
#
class CallUnits(unittest.TestCase):

    def testCase000(self):
        _s = sys.path[:]
        A = os.path.normpath('a/A.txt')         #@UnusedVariable
        B = os.path.normpath('a/b/B.txt')       #@UnusedVariable
        C = os.path.normpath('a/b/c/C.txt')     #@UnusedVariable
        D = os.path.normpath('a/b/c/d/D.txt')   #@UnusedVariable

        start = 'file://'+os.path.abspath(os.path.dirname(__file__)+os.sep+D)
        top = 'file://a/b'
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable
        
        mypos = os.path.abspath(os.path.normpath(os.path.dirname(__file__)+"/../../"))   
        res = []
        for i in range(len(_res)):
            pr = getPythonPathRel(_res[i],[mypos])
            if pr:
                res.append(pr)
        resx = ['110_uri/Case030/a/b/c/d', '110_uri/Case030/a/b/c', '110_uri/Case030/a/b']
        res = map(normpathX, res)
        resx = map(normpathX, resx)
        
        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        

        assert resx == res
        pass

    def testCase001(self):
        _s = sys.path[:]
        A = os.path.normpath('a/A.txt')         #@UnusedVariable
        B = os.path.normpath('a/b/B.txt')       #@UnusedVariable
        C = os.path.normpath('a/b/c/C.txt')     #@UnusedVariable
        D = os.path.normpath('a/b/c/d/D.txt')   #@UnusedVariable

        start = 'file://'+os.path.normpath(os.path.abspath(os.path.dirname(__file__)+os.sep+D))
        top = 'file://'+os.path.normpath('a/b')
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable

        mypos = os.path.abspath(os.path.normpath(os.path.dirname(__file__)+"/../../"))   
        res = []
        for i in range(len(_res)):
            pr = getPythonPathRel(_res[i],[mypos])
            if pr:
                res.append(pr)
        resx =  ['110_uri\\Case030\\a\\b\\c\\d', '110_uri\\Case030\\a\\b\\c', '110_uri\\Case030\\a\\b']
        res = map(normpathX, res)
        resx = map(normpathX, resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        self.assertEqual(resx, res)
        pass

    def testCase002(self):
        _s = sys.path[:]
        A = os.path.normpath('a/A.txt')         #@UnusedVariable
        B = os.path.normpath('a/b/B.txt')       #@UnusedVariable
        C = os.path.normpath('a/b/c/C.txt')     #@UnusedVariable
        D = os.path.normpath('a/b/c/d/D.txt')   #@UnusedVariable

        start = 'file://'+os.path.normpath(os.path.abspath(os.path.dirname(__file__)+os.sep+D))
        top = 'file://'+os.path.normpath('a/b')
        _res = []
        ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable

        mypos = os.path.abspath(os.path.normpath(os.path.dirname(__file__)+"/../../"))   
        res = []
        for i in range(len(_res)):
            pr = getPythonPathRel(_res[i],[mypos])
            if pr:
                res.append(pr)
        resx =  ['110_uri\\Case030\\a\\b\\c\\d', '110_uri\\Case030\\a\\b\\c', '110_uri\\Case030\\a\\b']
        res = map(normpathX, res)
        resx = map(normpathX, resx)

        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)
        
        assert resx == res
        pass

#FIXME: seems to be not required for now
#     def testCase010(self):
#         _s = sys.path[:]
#         A = os.path.normpath('a/A.txt')         #@UnusedVariable
#         B = os.path.normpath('a/b/B.txt')       #@UnusedVariable
#         C = os.path.normpath('a/b/c/C.txt')     #@UnusedVariable
#         D = os.path.normpath('a/b/c/d/D.txt')   #@UnusedVariable
# 
#         start = 'file://'+os.path.normpath(os.path.abspath(os.path.dirname(__file__)+os.sep+D))
# #        top = 'file://'+os.path.normpath('a/b')
#         top = os.path.normpath('a/b')
#         _res = []
#         ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable
# 
#         forDebugOnly = sys.path #@UnusedVariable
#         
#         res = []
#         for i in range(len(_res)):
#             res.append(getPythonPathRel(_res[i])) 
#         resx = [
#             '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/110_uri/Case030/a/b/c/d', 
#             '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/110_uri/Case030/a/b/c', 
#             '30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/110_uri/Case030/a/b'
# #             'tests/30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/110_uri/Case030/a/b/c/d', 
# #             'tests/30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/110_uri/Case030/a/b/c', 
# #             'tests/30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/110_uri/Case030/a/b'
#         ]
#         resx = map(os.path.normpath,resx)
# 
#         [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
#         sys.path.extend(_s)
#         
#         
#         print
#         print("-----")
#         print("4TEST:resx=  "+str(resx))
#         print("-----")
#         print("4TEST:res =   "+str(res))
# 
#         self.assertEqual(resx,res)
#         pass

    def testCase011(self):
#FIXME:
#         _s = sys.path[:]
#         A = os.path.normpath('a/A.txt')         #@UnusedVariable
#         B = os.path.normpath('a/b/B.txt')       #@UnusedVariable
#         C = os.path.normpath('a/b/c/C.txt')     #@UnusedVariable
#         D = os.path.normpath('a/b/c/d/D.txt')   #@UnusedVariable
# 
#         start = 'file://///'+os.path.normpath(os.path.abspath(os.path.dirname(__file__)+os.sep+D))
#         top = 'file://///'+os.path.normpath('a/b')
#         _res = []
#         ret = setUpperTreeSearchPath(start,top,_res) #@UnusedVariable
# 
#         forDebugOnly = sys.path #@UnusedVariable
#         
#         res = []
#         for i in range(len(_res)):
#             res.append(getPythonPathRel(_res[i])) 
#         resx = [
#             'tests/30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/110_uri/Case030/a/b/c/d', 
#             'tests/30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/110_uri/Case030/a/b/c', 
#             'tests/30_libs/040_FileSysObjects/070_setUpperTreeSearchPath/110_uri/Case030/a/b'
#         ]
#         resx = map(os.path.normpath, resx)
# 
#         [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
#         sys.path.extend(_s)
# 
#         assert resx == res
        pass


if __name__ == '__main__':
    unittest.main()



"""
Common test data
================
Common data for 'UseCases' and 'tests'. Refer to the package by PYTHONPATH.
The global variable 'testdata.mypath' provides the pathname into 'testdata'.
"""

import os
mypath = os.path.normpath(os.path.abspath(os.path.dirname(__file__)))



"""Demonstrates the application of hierarchical search paths on shared drives on Microsoft-Windows(TM). 

Type: SHARE

"""
from __future__ import absolute_import

import unittest
import os,sys
import platform

from pysourceinfo.PySourceInfo import getPythonPathRel
from filesysobjects.FileSysObjects import setUpperTreeSearchPath,getAppPrefixLocalPath,getTopFromPathString


#
#######################
#
class UseCase(unittest.TestCase):
    
    def testCase_SharedDriveC(self):
        #for now windows only
        if platform.system() != 'Windows':
            unittest.SkipTest("Requires Windows - skipped!")
            return True
        if not os.path.exists('\\\\localhost\\C$'):
            unittest.SkipTest("Requires share for this test - skipped!")
            return True
         
        _s = sys.path[:]
 
        _rtype = 'SHARE'
        _host = 'localhost'
        _share,sp = os.path.splitdrive(os.path.abspath(os.path.dirname(__file__))+os.path.normpath('/a/b///c/d/b/c///'))
        _share = 'C$'
        start = getAppPrefixLocalPath((_rtype, _host, _share,sp,))
 
        s = os.sep

        _rtype = 'SHARE'
        _host = 'localhost'
        sp = s+os.sep.join(sp.split(os.sep)[1:5])+s
        #sp = 2*s+os.sep.join(sp.split(os.sep)[1:5])+s
        _share = 'C$'
        top = getAppPrefixLocalPath((_rtype, _host, _share,sp,))

        _res = []
        ret = setUpperTreeSearchPath(start,top,_res,**{'reverse':True,}) #@UnusedVariable
         
        forDebugOnly = sys.path #@UnusedVariable
       
        _rtype = 'SHARE'
        _host = 'localhost'
        _share = 'C$'
        sp = sp
        mystart = getAppPrefixLocalPath((_rtype, _host, _share,sp,))
         
        mystart  = getTopFromPathString(top,[mystart])
        myplist = [mystart,]
        res = []
        for i in range(len(_res)):
            res.append(getPythonPathRel(_res[i],myplist)) 
             
        resx = [
            '.',
            'UseCases',
            'UseCases/FileSysObjects',
            'UseCases/FileSysObjects/AppPathSyntax',
            'UseCases/FileSysObjects/AppPathSyntax/win_share',
            'UseCases/FileSysObjects/AppPathSyntax/win_share/share_drives',
            'UseCases/FileSysObjects/AppPathSyntax/win_share/share_drives/a',
            'UseCases/FileSysObjects/AppPathSyntax/win_share/share_drives/a/b',
            'UseCases/FileSysObjects/AppPathSyntax/win_share/share_drives/a/b/c',
            'UseCases/FileSysObjects/AppPathSyntax/win_share/share_drives/a/b/c/d',
            'UseCases/FileSysObjects/AppPathSyntax/win_share/share_drives/a/b/c/d/b',
            'UseCases/FileSysObjects/AppPathSyntax/win_share/share_drives/a/b/c/d/b/c',
        ]
        resx = map(os.path.normpath,resx)
 
        [ sys.path.pop() for x in range(len(sys.path)) ] #@UnusedVariable
        sys.path.extend(_s)

        assert resx == res
        pass
 
if __name__ == '__main__':
    unittest.main()




from __future__ import absolute_import
from linecache import getline


__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os,sys

import filesysobjects.FileSysObjects
import pysourceinfo.PySourceInfo

#
#######################
#


class CallUnits(unittest.TestCase):
    """Network resources IEEE.1003.1/CIFS/SMB/UNC - respect hostname
    """

    def testCase000(self):
        """Respect 'hostname', which is actual hostname, and a node name.
        """
        s = os.sep
        s2 = 2*s
        s5 = 2*s
        s8 = 8*s
        start = s2+'hostname'+s+'tests'+s8+'a'+s+'b'+s+'hostname'+s2+'c'+s5+'d'+s+'tests'+s+'b'+s2+'c'
        top = 'hostname'+s
        top = filesysobjects.FileSysObjects.getTopFromPathString(top, [start]) #@UnusedVariable
        start = os.path.normpath(top)
        top0ref=os.path.normpath(r'//hostname/tests/a/b/hostname')

        self.assertEqual(top0ref, top) 
        pass

    def testCase001(self):
        """Respect 'hostname', which is actual hostname, and a node name.
        """
        s = os.sep
        s2 = 2*s
        s5 = 2*s
        s8 = 8*s
        start = s2+'hostname'+s+'tests'+s8+'a'+s+'b'+s+'hostname'+s2+'c'+s5+'d'+s+'tests'+s+'b'+s2+'c'
        top = 'hostname'
        top = filesysobjects.FileSysObjects.getTopFromPathString(top, [start]) #@UnusedVariable
        start = os.path.normpath(top)
        top0ref=os.path.normpath(r'//hostname/tests/a/b/hostname')

        self.assertEqual(top0ref, top) 
        pass

#
#######################
#

if __name__ == '__main__':
    unittest.main()




# -*- coding: utf-8 -*-
"""The 'NetFiles' module provides basic extensions for 'os.path.normpath'.  

**REMARK**: This module is currently an experimental release for discussion 
   and may change. Do not use it in production code!

The following subset of URLs / RFC...
"""
from __future__ import absolute_import

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.1.1'
__uuid__='a4662fc5-973b-42b8-9cf4-427d42dcba5e'

__docformat__ = "restructuredtext en"

import os,sys
version = '{0}.{1}'.format(*sys.version_info[:2])
if version < '2.7': # pragma: no cover
    raise Exception("Requires Python-2.7.* or higher")

from types import NoneType

from pysourceinfo.PySourceInfo import getCallerFilePathName,getPythonPathRel

class NetFilesException(Exception):
    pass

#
# for test and development
_mydebug = False
#_mydebug = True

#
# supported URIs
#
import re
#keyword patterns and match vector indexes
_COMP = re.compile(r"(((smb://)([^/]+)([^:]*))|((cifs://)([^/]+)([^:]*))|((http://)([^/][^/]*)([^:]*))|((https://)([^/][^/]*)([^:]*))|((file://)()([^:]*))|(()()([^:]*)))[:]*")
_COMPI = [ 3, 7, 11, 15, 19, 23, ]
def netNormpathX(path,**kargs):
    """Extends 'os.path.normpathX' for network filesystems applications.

    The basic extension is the split of the full application level pathname
    into it's application parts and the actual pathname of the node. The 
    pathname of the node is still passed onto the call 'os.path.normpath',
    with a few exceptions only, whereas the network application part, and/or
    eventual protocol key of the URI are handled separately.

    Thus the behavior for the filesystem address - the local path almost
    remains, while is extended by a network portion.

    But due to the eventual different remote filesystem attributes the local
    evaluation remains unsafe, while else requires remote access for assurance
    of the parameters.
    
    #FIXME: Going to be worked out!

    Args:
        plist: List of paths to be cleared.
            See common options for details.
            
            default := sys.path

        **kargs:
            fstype: The type of the final target filesystem.
                This is required because a remote filesystem 
                could be 's.th.' completely different, e.g.
                just a virtual representation of anything.
                 
                default := <local-filesystem-type>

            ias: Treats for local file names any 
                number of subsequent 'os.pathsep' as one.
                This breaks formally the definitions on IEEE-1003.1,
                and SMB/CIFS conformant filesystems.
                
                See common options for more details.
                
            raw: Suppress of the call of 'os.path.normpath' and
                the generic term 'share'.

    Returns:
        When successful returns the split file pathname, else returns 
        either 'None', or raises an exception.

    Raises:
        passed through exceptions:
    """
    _fstype = False
    _ias = False
    _raw = False
    
    for k,v in kargs.items():
        if k == 'fstype':
            _fstype = v
        elif k == 'raw':
            _raw = v
        elif k == 'ias':
            _ias = v

    def clearp(p):
        p = p[1:].lstrip(os.sep)
        if _ias and p[:2] == os.sep+os.sep:
            p = p[1:]
        return p

    for i in _COMP.finditer(path):
        for g in _COMPI:
            if i.group(g): # a uri
                return (i.group(g)[:-3], i.group(g+1), clearp(i.group(g+2))) # returns one only
            elif i.group(g+2): # the local filesystem
                return (i.group(g)[:-3], i.group(g+1), clearp(i.group(g+2))) # returns one only
    return None



from __future__ import absolute_import
from linecache import getline

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import os
import tests.CheckEscUnesc

import filesysobjects.FileSysObjects
#
#######################
#


class CallUnits(tests.CheckEscUnesc.CheckEscUnesc):

    def testCase000(self):
        _in        = '//hostname\a\\b/c'
        _esc     = r'//hostname\\a\\b/c'
        _unesc = r'//hostname\a\b/c'
        self.check_esc_unesc(_in,_esc,_unesc,'k')
        
    def testCase010(self):
        _in        = '\\hostname/a\b/c'
        _esc     = r'\\hostname/a\\b/c'
        _unesc = r'\hostname/a\b/c'
        self.check_esc_unesc(_in,_esc,_unesc,'k')
        
    def testCase020(self):
        _in        = '\\\\hostname\a/////b\c'
        _esc     = r'\\\\hostname\\a/b\\c'
        _unesc = r'\\hostname\a/b\c'
        self.check_esc_unesc(_in,_esc,_unesc,'k')

    def testCase100(self):
        _in        = '//hostname\a\\b/c'
        _esc     = r'//hostname\\a\\b/c'
        _unesc = r'//hostname\a\b/c'
        self.check_esc_unesc(_in,_esc,_unesc,'k')

        np = filesysobjects.FileSysObjects.normpathX(_unesc)
        npx = _unesc.replace('/', os.sep)
        npx = npx.replace('\\', os.sep)
        assert np == npx
        
    def testCase110(self):
        _in        = '\\hostname/a\b/c'
        _esc     = r'\\hostname/a\\b/c'
        _unesc = r'\hostname/a\b/c'
        self.check_esc_unesc(_in,_esc,_unesc,'k')

        np = filesysobjects.FileSysObjects.normpathX(_unesc)
        npx = _unesc.replace('/', os.sep)
        npx = npx.replace('\\', os.sep)
        assert np == npx
        
    def testCase120(self):
        _in        = '\\\\hostname\a/////b\c'
        _esc     = r'\\\\hostname\\a/b\\c'
        _unesc = r'\\hostname\a/b\c'
        self.check_esc_unesc(_in,_esc,_unesc,'k')

        np = filesysobjects.FileSysObjects.normpathX(_unesc)
        npx = _unesc.replace('/', os.sep)
        npx = npx.replace('\\', os.sep)
        assert np == npx

    def testCase210(self):
        _in        = 'file://\\\\hostname\a/////b\c'
        _esc     = r'file://\\\\hostname\\a/b\\c'    #FIXME: verify this interpretation
        _unesc = r'file://\\hostname\a/b\c'     #FIXME: verify this interpretation
        self.check_esc_unesc(_in,_esc,_unesc,'k')

#
#######################
#

if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

__author__ = 'Arno-Can Uestuensoez'
__license__ = "Artistic-License-2.0 + Forced-Fairplay-Constraints"
__copyright__ = "Copyright (C) 2010-2016 Arno-Can Uestuensoez @Ingenieurbuero Arno-Can Uestuensoez"
__version__ = '0.0.1'
__uuid__='af90cc0c-de54-4a32-becd-06f5ce5a3a75'

__docformat__ = "restructuredtext en"

import unittest
import tests.CheckEscUnesc

import filesysobjects.FileSysObjects

#
#######################
#


class CallUnits(tests.CheckEscUnesc.CheckEscUnesc):

    def testCase110(self):
        _in        = '\\\\a\a\b\c'
        _esc     = r'\\\\a\\a\\b\\c'
        _unesc = r'\\a\a\b\c'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')

    def testCase112(self):
        _in        = r'\\a\a\b\c'
        _esc     = r'\\\\a\\a\\b\\c'
        _unesc = r'\\a\a\b\c'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')

    def testCase113(self):
        _in        = r'\\\\a\\a\\b\\c'
        _esc     = r'\\a\\a\\b\\c'
        _unesc = r'\a\a\b\c'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')

    def testCase114(self):
        _in        = '\\\\a\\\\a\\\\b\\\\c'
        _esc     = r'\\\\a\\a\\b\\c'
        _unesc = r'\\a\a\b\c'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')

    def testCase115(self):
        _in        = '\\\\a\a\\\\b\c'
        _esc     = r'\\\\a\\a\\b\\c'
        _unesc = r'\\a\a\b\c'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')

    def testCase116(self):
        _in        = '\a\a\\\\b\c'
        _esc     = r'\\a\\a\\b\\c'
        _unesc = r'\a\a\b\c'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')

    def testCase120(self):
        _in        = '\\\\t\v\\\n'
        _esc     = r'\\\\t\\v\\n'
        _unesc = r'\\t\v\n'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')

    def testCase130(self):
        _in        = '\\\\' 'x\\' 'x' '\\x'
        _esc     = r'\\\\x\\x\\x'
        _unesc = r'\\x\x\x'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')

    def testCase131(self):
        _in        = '\\\\a\a\\\a'
        _esc     = r'\\\\a\\a\\a'
        _unesc = r'\\a\a\a'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')

    def testCase132(self):
        _in        = '\\\\b\b\\\b'
        _esc     = r'\\\\b\\b\\b'
        _unesc = r'\\b\b\b'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')

    def testCase133(self):
        _in        = '\\\\f\f\\\f'
        _esc     = r'\\\\f\\f\\f'
        _unesc = r'\\f\f\f'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')
    
    def testCase134(self):
        _in        = '\\\\n\n\\\n'
        _esc     = r'\\\\n\\n\\n'
        _unesc = r'\\n\n\n'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')
        
    def testCase135(self):
        _in        = '\\\\r\r\\\r'
        _esc     = r'\\\\r\\r\\r'
        _unesc = r'\\r\r\r'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')
        
    def testCase136(self):
        _in        = '\\\\t\t\\\t'
        _esc     = r'\\\\t\\t\\t'
        _unesc = r'\\t\t\t'
        self.check_esc_unesc(_in,_esc,_unesc, 'k')

#
#######################
#

if __name__ == '__main__':
    unittest.main()
